==> apache-nuttx-9.1.1-incubating.tar.gz: nuttx/arch/sim/include/limits.h <==
/****************************************************************************
 * arch/sim/include/limits.h
 *
 *   Copyright (C) 2007, 2009, 2012 Gregory Nutt. All rights reserved.
 *   Author: Gregory Nutt <gnutt@nuttx.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 3. Neither the name NuttX nor the names of its contributors may be
 *    used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/

#ifndef __ARCH_SIM_INCLUDE_LIMITS_H
#define __ARCH_SIM_INCLUDE_LIMITS_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

#define CHAR_BIT     8
#define SCHAR_MIN    (-SCHAR_MAX - 1)
#define SCHAR_MAX    127
#define UCHAR_MAX    255

/* These could be different on machines where char is unsigned */

#ifdef __CHAR_UNSIGNED__
#define CHAR_MIN     0
#define CHAR_MAX     UCHAR_MAX
#else
#define CHAR_MIN     SCHAR_MIN
#define CHAR_MAX     SCHAR_MAX
#endif

#define SHRT_MIN     (-SHRT_MAX - 1)
#define SHRT_MAX     32767
#define USHRT_MAX    65535U

#define INT_MIN      (-INT_MAX - 1)
#define INT_MAX      2147483647
#define UINT_MAX     4294967295U

/* These change on 32-bit and 64-bit platforms */

#if !defined(CONFIG_HOST_X86_64) || defined(CONFIG_SIM_M32)
#  define LONG_MIN   (-LONG_MAX - 1)
#  define LONG_MAX   2147483647L
#  define ULONG_MAX  4294967295UL
#else
#  define LONG_MIN   (-LLONG_MAX - 1)
#  define LONG_MAX   9223372036854775807LL
#  define ULONG_MAX  18446744073709551615ULL
#endif

#define LLONG_MIN    (-LLONG_MAX - 1)
#define LLONG_MAX    9223372036854775807LL
#define ULLONG_MAX   18446744073709551615ULL

/* A pointer is 4 or 8 bytes */

#define PTR_MIN      (-PTR_MAX - 1)
#if !defined(CONFIG_HOST_X86_64) || defined(CONFIG_SIM_M32)
#  define PTR_MAX    2147483647
#  define UPTR_MAX   4294967295U
#else
#  define PTR_MAX    9223372036854775807LL
#  define UPTR_MAX   18446744073709551615ULL
#endif

#endif /* __ARCH_SIM_INCLUDE_LIMITS_H  */

==> apache-nuttx-10.1.0-incubating.tar.gz: nuttx/arch/sim/include/limits.h <==
/****************************************************************************
 * arch/sim/include/limits.h
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

#ifndef __ARCH_SIM_INCLUDE_LIMITS_H
#define __ARCH_SIM_INCLUDE_LIMITS_H

/****************************************************************************
 * Included Files
 ****************************************************************************/

/****************************************************************************
 * Pre-processor Definitions
 ****************************************************************************/

#define CHAR_BIT     8
#define SCHAR_MIN    (-SCHAR_MAX - 1)
#define SCHAR_MAX    127
#define UCHAR_MAX    255

/* These could be different on machines where char is unsigned */

#ifdef __CHAR_UNSIGNED__
#define CHAR_MIN     0
#define CHAR_MAX     UCHAR_MAX
#else
#define CHAR_MIN     SCHAR_MIN
#define CHAR_MAX     SCHAR_MAX
#endif

#define SHRT_MIN     (-SHRT_MAX - 1)
#define SHRT_MAX     32767
#define USHRT_MAX    65535U

#define INT_MIN      (-INT_MAX - 1)
#define INT_MAX      2147483647
#define UINT_MAX     4294967295U

/* These change on 32-bit and 64-bit platforms */

#if !defined(CONFIG_HOST_X86_64) || defined(CONFIG_SIM_M32)
#  define LONG_MIN   (-LONG_MAX - 1)
#  define LONG_MAX   2147483647L
#  define ULONG_MAX  4294967295UL
#else
#  define LONG_MIN   (-LONG_MAX - 1)
#  define LONG_MAX   9223372036854775807L
#  define ULONG_MAX  18446744073709551615UL
#endif

#define LLONG_MIN    (-LLONG_MAX - 1)
#define LLONG_MAX    9223372036854775807LL
#define ULLONG_MAX   18446744073709551615ULL

/* A pointer is 4 or 8 bytes */

#define PTR_MIN      (-PTR_MAX - 1)
#if !defined(CONFIG_HOST_X86_64) || defined(CONFIG_SIM_M32)
#  define PTR_MAX    2147483647
#  define UPTR_MAX   4294967295U
#else
#  define PTR_MAX    9223372036854775807LL
#  define UPTR_MAX   18446744073709551615ULL
#endif

#endif /* __ARCH_SIM_INCLUDE_LIMITS_H  */
